==> kvirc-3.2.6.tar.bz2: kvirc-3.2.6/src/kvirc/kernel/kvi_coreactionnames.h <==
#ifndef _KVI_COREACTIONNAMES_H_
#define _KVI_COREACTIONNAMES_H_
//=============================================================================
//
//   File : kvi_coreactionnames.h
//   Created on Mon 22 Nov 2004 02:30:47 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC Client distribution
//   Copyright (C) 2004 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//=============================================================================

#define KVI_COREACTION_NAME_PREFIX "kvirc."

#define KVI_COREACTION_SERVEROPTIONS (KVI_COREACTION_NAME_PREFIX "serveroptions")
#define KVI_COREACTION_IDENTITYOPTIONS (KVI_COREACTION_NAME_PREFIX "identityoptions")
#define KVI_COREACTION_SOCKETSPY (KVI_COREACTION_NAME_PREFIX "socketspy")
#define KVI_COREACTION_NETWORKLINKS (KVI_COREACTION_NAME_PREFIX "networklinks")
#define KVI_COREACTION_CHANNELLIST (KVI_COREACTION_NAME_PREFIX "channellist")
#define KVI_COREACTION_GENERALOPTIONS (KVI_COREACTION_NAME_PREFIX "generaloptions")
#define KVI_COREACTION_TOOLBAREDITOR (KVI_COREACTION_NAME_PREFIX "toolbareditor")
#define KVI_COREACTION_JOINCHANNELS (KVI_COREACTION_NAME_PREFIX "joinchannels")
#define KVI_COREACTION_ACTIONEDITOR (KVI_COREACTION_NAME_PREFIX "actioneditor")
#define KVI_COREACTION_ALIASEDITOR (KVI_COREACTION_NAME_PREFIX "aliaseditor")
#define KVI_COREACTION_EVENTEDITOR (KVI_COREACTION_NAME_PREFIX "eventeditor")
#define KVI_COREACTION_POPUPEDITOR (KVI_COREACTION_NAME_PREFIX "popupeditor")
#define KVI_COREACTION_RAWEDITOR (KVI_COREACTION_NAME_PREFIX "raweditor")
#define KVI_COREACTION_CODETESTER (KVI_COREACTION_NAME_PREFIX "codetester")
#define KVI_COREACTION_EXECUTEKVS (KVI_COREACTION_NAME_PREFIX "executekvs")
#define KVI_COREACTION_CASCADEWINDOWS (KVI_COREACTION_NAME_PREFIX "cascadewindows")
#define KVI_COREACTION_TILEWINDOWS (KVI_COREACTION_NAME_PREFIX "tilewindows")
#define KVI_COREACTION_MINIMIZEALLWINDOWS (KVI_COREACTION_NAME_PREFIX "minimizeallwindows")
#define KVI_COREACTION_NEWIRCCONTEXT (KVI_COREACTION_NAME_PREFIX "newirccontext")
#define KVI_COREACTION_QUITKVIRC (KVI_COREACTION_NAME_PREFIX "quitkvirc")
#define KVI_COREACTION_IRCCONTEXTDISPLAY (KVI_COREACTION_NAME_PREFIX "irccontextdisplay")
#define KVI_COREACTION_SEPARATOR (KVI_COREACTION_NAME_PREFIX "separator")
#define KVI_COREACTION_CONNECT (KVI_COREACTION_NAME_PREFIX "connect")
#define KVI_COREACTION_CHANNELMENU (KVI_COREACTION_NAME_PREFIX "channelmenu")
#define KVI_COREACTION_NICKNAMEMENU (KVI_COREACTION_NAME_PREFIX "nicknamemenu")
#define KVI_COREACTION_SERVERMENU (KVI_COREACTION_NAME_PREFIX "servermenu")
#define KVI_COREACTION_USERMODEMENU (KVI_COREACTION_NAME_PREFIX "usermodemenu")
#define KVI_COREACTION_AWAYBACK (KVI_COREACTION_NAME_PREFIX "awayback")
#define KVI_COREACTION_IRCTOOLS (KVI_COREACTION_NAME_PREFIX "irctools")
#define KVI_COREACTION_IRCACTIONS (KVI_COREACTION_NAME_PREFIX "ircactions")
#define KVI_COREACTION_HELPINDEX (KVI_COREACTION_NAME_PREFIX "helpindex")
#define KVI_COREACTION_KVIRCMAILINGLIST (KVI_COREACTION_NAME_PREFIX "kvircmailinglist")
#define KVI_COREACTION_KVIRCHOMEPAGE (KVI_COREACTION_NAME_PREFIX "kvirchomepage")
#define KVI_COREACTION_KVIRCRUHOMEPAGE (KVI_COREACTION_NAME_PREFIX "kvircruhomepage")
#define KVI_COREACTION_EDITREGUSERS (KVI_COREACTION_NAME_PREFIX "editregusers")
#define KVI_COREACTION_MANAGEADDONS (KVI_COREACTION_NAME_PREFIX "manageaddons")
#define KVI_COREACTION_THEMEOPTIONS (KVI_COREACTION_NAME_PREFIX "themeoptions")
#define KVI_COREACTION_MANAGETHEMES (KVI_COREACTION_NAME_PREFIX "managethemes")

#endif //!_KVI_COREACTIONNAMES_H_

==> kvirc-4.0rc3.tar.bz2: kvirc-4.0rc3/src/kvirc/kernel/kvi_coreactionnames.h <==
#ifndef _KVI_COREACTIONNAMES_H_
#define _KVI_COREACTIONNAMES_H_
//=============================================================================
//
//   File : kvi_coreactionnames.h
//   Creation date : Mon 22 Nov 2004 02:30:47 by Szymon Stefanek
//
//   This file is part of the KVIrc IRC Client distribution
//   Copyright (C) 2004-2008 Szymon Stefanek <pragma at kvirc dot net>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
//
//=============================================================================

#define KVI_COREACTION_NAME_PREFIX "kvirc."

#define KVI_COREACTION_SERVEROPTIONS (KVI_COREACTION_NAME_PREFIX "serveroptions")
#define KVI_COREACTION_IDENTITYOPTIONS (KVI_COREACTION_NAME_PREFIX "identityoptions")
#define KVI_COREACTION_SOCKETSPY (KVI_COREACTION_NAME_PREFIX "socketspy")
#define KVI_COREACTION_NETWORKLINKS (KVI_COREACTION_NAME_PREFIX "networklinks")
#define KVI_COREACTION_CHANNELLIST (KVI_COREACTION_NAME_PREFIX "channellist")
#define KVI_COREACTION_GENERALOPTIONS (KVI_COREACTION_NAME_PREFIX "generaloptions")
#define KVI_COREACTION_TOOLBAREDITOR (KVI_COREACTION_NAME_PREFIX "toolbareditor")
#define KVI_COREACTION_JOINCHANNELS (KVI_COREACTION_NAME_PREFIX "joinchannels")
#define KVI_COREACTION_ACTIONEDITOR (KVI_COREACTION_NAME_PREFIX "actioneditor")
#define KVI_COREACTION_ALIASEDITOR (KVI_COREACTION_NAME_PREFIX "aliaseditor")
#define KVI_COREACTION_CLASSEDITOR (KVI_COREACTION_NAME_PREFIX "classeditor")
#define KVI_COREACTION_EVENTEDITOR (KVI_COREACTION_NAME_PREFIX "eventeditor")
#define KVI_COREACTION_POPUPEDITOR (KVI_COREACTION_NAME_PREFIX "popupeditor")
#define KVI_COREACTION_RAWEDITOR (KVI_COREACTION_NAME_PREFIX "raweditor")
#define KVI_COREACTION_CODETESTER (KVI_COREACTION_NAME_PREFIX "codetester")
#define KVI_COREACTION_EXECUTEKVS (KVI_COREACTION_NAME_PREFIX "executekvs")
#define KVI_COREACTION_CASCADEWINDOWS (KVI_COREACTION_NAME_PREFIX "cascadewindows")
#define KVI_COREACTION_TILEWINDOWS (KVI_COREACTION_NAME_PREFIX "tilewindows")
#define KVI_COREACTION_MINIMIZEALLWINDOWS (KVI_COREACTION_NAME_PREFIX "minimizeallwindows")
#define KVI_COREACTION_NEWIRCCONTEXT (KVI_COREACTION_NAME_PREFIX "newirccontext")
#define KVI_COREACTION_QUITKVIRC (KVI_COREACTION_NAME_PREFIX "quitkvirc")
#define KVI_COREACTION_IRCCONTEXTDISPLAY (KVI_COREACTION_NAME_PREFIX "irccontextdisplay")
#define KVI_COREACTION_SEPARATOR (KVI_COREACTION_NAME_PREFIX "separator")
#define KVI_COREACTION_CONNECT (KVI_COREACTION_NAME_PREFIX "connect")
#define KVI_COREACTION_CHANNELMENU (KVI_COREACTION_NAME_PREFIX "channelmenu")
#define KVI_COREACTION_NICKNAMEMENU (KVI_COREACTION_NAME_PREFIX "nicknamemenu")
#define KVI_COREACTION_SERVERMENU (KVI_COREACTION_NAME_PREFIX "servermenu")
#define KVI_COREACTION_USERMODEMENU (KVI_COREACTION_NAME_PREFIX "usermodemenu")
#define KVI_COREACTION_AWAYBACK (KVI_COREACTION_NAME_PREFIX "awayback")
#define KVI_COREACTION_IRCTOOLS (KVI_COREACTION_NAME_PREFIX "irctools")
#define KVI_COREACTION_IRCACTIONS (KVI_COREACTION_NAME_PREFIX "ircactions")
#define KVI_COREACTION_HELPINDEX (KVI_COREACTION_NAME_PREFIX "helpindex")
#define KVI_COREACTION_KVIRCMAILINGLIST (KVI_COREACTION_NAME_PREFIX "kvircmailinglist")
#define KVI_COREACTION_KVIRCHOMEPAGE (KVI_COREACTION_NAME_PREFIX "kvirchomepage")
#define KVI_COREACTION_KVIRCRUHOMEPAGE (KVI_COREACTION_NAME_PREFIX "kvircruhomepage")
#define KVI_COREACTION_EDITREGUSERS (KVI_COREACTION_NAME_PREFIX "editregusers")
#define KVI_COREACTION_MANAGEADDONS (KVI_COREACTION_NAME_PREFIX "manageaddons")
#define KVI_COREACTION_THEMEOPTIONS (KVI_COREACTION_NAME_PREFIX "themeoptions")
#define KVI_COREACTION_MANAGETHEMES (KVI_COREACTION_NAME_PREFIX "managethemes")
#define KVI_COREACTION_SCREENSHOT (KVI_COREACTION_NAME_PREFIX "screenshot")

#endif //!_KVI_COREACTIONNAMES_H_
